@@ -8,7 +8,7 @@ require_once 'aselect/client.php';
  *
  * @author Wessel Dankers, Tilburg University
  */
-class sspmod_aselect_Auth_Source_ASelectAgent extends SimpleSAML_Auth_Source {
+class sspmod_aselectagent_Auth_Source_ASelectAgent extends SimpleSAML_Auth_Source {
 	// A-Select application ID
 	private $app_id;
 
@@ -36,7 +36,7 @@ class sspmod_aselect_Auth_Source_ASelectAgent extends SimpleSAML_Auth_Source {
 	public function authenticate(&$state) {
 		$id = SimpleSAML_Auth_State::saveState($state, 'aselectagent:login', true);
 
-		$app_url = SimpleSAML_Module::getModuleURL('aselect/credentials.php', array('ssp_state' => $id));
+		$app_url = SimpleSAML_Module::getModuleURL('aselectagent/credentials.php', array('ssp_state' => $id));
 		$as_url = aselect_authenticate($this->app_id, $app_url);
 		if(is_null($as_url))
 			SimpleSAML_Auth_State::throwException($state, new SimpleSAML_Error_Exception("Unable to acquire A-Select login URL"));
